import { openDB } from 'idb';

const DB_NAME = 'BarcodeDB';
const STORE_NAME = 'barcodes';
const DB_VERSION = 2;

async function getDB() {
  return openDB(DB_NAME, DB_VERSION, {
    upgrade(db, oldVersion, newVersion, tx) {
      if (!db.objectStoreNames.contains(STORE_NAME)) {
        const store = db.createObjectStore(STORE_NAME, {
          keyPath: 'id',
          autoIncrement: true,
        });
        store.createIndex('code', 'code', { unique: false });
        store.createIndex('createdAt', 'createdAt', { unique: false });
      }

      if (oldVersion < 2) {
        const store = tx.objectStore(STORE_NAME);
        if (!store.indexNames.contains('tags')) {
          store.createIndex('tags', 'tags', { multiEntry: true });
        }
      }
    },
  });
}

export async function addBarcode(code) {
  const db = await getDB();
  const tx = db.transaction(STORE_NAME, 'readwrite');
  const store = tx.objectStore(STORE_NAME);
  await store.add({ code, createdAt: new Date(), tags: [] });
  await tx.done;
}

export async function getAllBarcodes() {
  const db = await getDB();
  return db.getAll(STORE_NAME);
}

export async function deleteBarcode(id) {
  const db = await getDB();
  const tx = db.transaction(STORE_NAME, 'readwrite');
  await tx.objectStore(STORE_NAME).delete(id);
  await tx.done;
}

export async function updateBarcodeTags(id, tags) {
  const db = await getDB();
  const tx = db.transaction(STORE_NAME, 'readwrite');
  const store = tx.objectStore(STORE_NAME);
  const record = await store.get(id);
  if (record) {
    record.tags = tags;
    await store.put(record);
  }
  await tx.done;
}
